==> qcad-3.17.3.0-1-armv6h.pkg.tar.xz: usr/lib/qcad/scripts/Help/About/AboutCredits.js <==
var credits = 
[
    [
        qsTr("Programming"),
        [ "Andrew Mustun",    "Main developer<br>"
                              ],
        [ "Christian Aigner", "Misc > Draw > Dovetail from 2 Points<br>"
                              ],
        [ "Matfie",           "Gear generator library item \"InvoluteSpur\"<br>"
                              ],
        [ "Matthias Melcher", "Drawing box joint lines<br>" +
                              "Drawing dovetail joint lines<br>" +
                              "MOL file import<br>"
                              ],
        [ "Marco Ferrara",    "Double-click to select contour<br>" +
                              "Block > Create Block from Selection: overwrite blocks<br>"
                              ],
        [ "Norbert K.",       "Modify > Break out Gap<br>"
                              ],
        [ "Robert S.",        "Direct distance entry<br>" +
                              "Selecting overlapping entities<br>" +
                              "Polyline area calculation<br>" +
                              "Command line calculator<br>" +
                              "Edit > Draw Preferences > General > Point Display<br>" +
                              "Edit > Convert Unit<br>" +
                              "View > Display Distance/Angle<br>" +
                              "Draw > Shape > Polygon (Center, Side)<br>" +
                              "Draw > Shape > Polygon (Side, Side)<br>" +
                              "Draw > Arc > 2 Points and Length<br>" +
                              "Draw > Arc > 2 Points and Height<br>" +
                              "Modify > Break out Manual<br>" +
                              "Snap > X/Y from Points<br>" +
                              "Snap > Y/X from Points<br>" +
                              "Snap > Distance Manual<br>" +
                              "Misc > Draw > Centerline Cross<br>" +
                              "Misc > Draw > Counter<br>" +
                              "Misc > Draw > Text Along<br>" +
                              "Misc > Development > Run Script<br>" +
                              "<i>Significant contributions to:</i><br>" +
                              "Draw > Line > Line from 2 Points<br>" +
                              "Draw > Polyline > Draw Polyline<br>" +
                              "Info > Arc/Circle/Ellipse Area<br>" +
                              "Custom linetype support, loading .lin files<br>"
                              ],
        [ "Tamas Tevesz",     "Port to FreeBSD<br>" +
                              "Various improvements and fixes<br>"
                              ],
        [ "Weston Schmidt",   "Draw > Dimension > Per-dimension scaling<br>"
                              ],
    ],
    [
        qsTr("Translations"),
        //[ "Wang Zhen Zhe",     "Chinese (zh_CN) translation." ],
        [ "Petr Zgraja",       "Czech (cs) translation" ],
        [ "Andrew Mustun",     "Dutch (nl) translation" ],
        [ "Timo Seppola",      "Finnish (fi) translation" ],
        [ "Andrew Mustun",     "German (de) translation" ],
        [ "Fabrizio Margini",  "Italian (it) translation" ],
        [ "Tanaka Hidemune",   "Japanese (ja) translation and user reference manual" ],
        [ "Евгений, AlexL",    "Russian (ru) translation" ],
        [ "Ján Jamriška",      "Slovak (sk) translation" ],
        [ "Miha ('miharix')",  "Slovenian (sl) translation" ],
        [ "Eduardo Passeto",   "Portuguese (pt) translation" ],
    ],
    [
        qsTr("Templates"),
        [ "Clive Tubb ('clive')", "ISO/AEC templates" ],
        [ "Frank ('DL3DL')",   "German templates DIN6771-1, DIN7200" ],
        [ "Miha ('miharix')",  "Slowenian Templates (OŠ)" ],
    ],
    [
        qsTr("Icons"),
        [ "Ralf Blumhagen ('blumi')",   "Icons for Apollonius tools in Misc > Drawing" ],
    ],
    [
        qsTr("Testing, Feedback and Minor Fixes"),
        [ "Clive Tubb ('clive')", "" ],
        [ "Harald Huesges ('Husky')", "" ],
        [ "and many others", "" ],
    ]
];

==> qcad-3.21.3.1-1-armv6h.pkg.tar.xz: usr/lib/qcad/scripts/Help/About/AboutCredits.js <==
var credits = 
[
    [
        qsTr("Programming"),
        [ "Andrew Mustun",    "Main developer<br>"
                              ],
        [ "Christian Aigner", "Misc > Draw > Dovetail from 2 Points<br>"
                              ],
        [ "Matfie",           "Gear generator library item \"InvoluteSpur\"<br>"
                              ],
        [ "Matthias Melcher", "Drawing box joint lines<br>" +
                              "Drawing dovetail joint lines<br>" +
                              "MOL file import<br>"
                              ],
        [ "Marco Ferrara",    "Double-click to select contour<br>" +
                              "Block > Create Block from Selection: overwrite blocks<br>"
                              ],
        [ "Norbert K.",       "Modify > Break out Gap<br>"
                              ],
        [ "Robert S.",        "Direct distance entry<br>" +
                              "Selecting overlapping entities<br>" +
                              "Polyline area calculation<br>" +
                              "Command line calculator<br>" +
                              "Edit > Draw Preferences > General > Point Display<br>" +
                              "Edit > Convert Unit<br>" +
                              "View > Display Distance/Angle<br>" +
                              "Draw > Shape > Polygon (Center, Side)<br>" +
                              "Draw > Shape > Polygon (Side, Side)<br>" +
                              "Draw > Arc > 2 Points and Length<br>" +
                              "Draw > Arc > 2 Points and Height<br>" +
                              "Modify > Break out Manual<br>" +
                              "Snap > X/Y from Points<br>" +
                              "Snap > Y/X from Points<br>" +
                              "Snap > Distance Manual<br>" +
                              "Misc > Draw > Centerline Cross<br>" +
                              "Misc > Draw > Counter<br>" +
                              "Misc > Draw > Text Along<br>" +
                              "Misc > Development > Run Script<br>" +
                              "<i>Significant contributions to:</i><br>" +
                              "Draw > Line > Line from 2 Points<br>" +
                              "Draw > Polyline > Draw Polyline<br>" +
                              "Info > Arc/Circle/Ellipse Area<br>" +
                              "Custom linetype support, loading .lin files<br>"
                              ],
        [ "Tamas Tevesz",     "Port to FreeBSD<br>" +
                              "Various improvements and fixes<br>"
                              ],
        [ "Weston Schmidt",   "Draw > Dimension > Per-dimension scaling<br>"
                              ],
    ],
    [
        qsTr("Translations"),
        //[ "Wang Zhen Zhe",     "Chinese (zh_CN) translation." ],
        [ "Petr Zgraja, fialot", "Czech (cs) translation" ],
        [ "Andrew Mustun",       "Dutch (nl) translation" ],
        [ "Timo Seppola",        "Finnish (fi) translation" ],
        [ "Andrew Mustun",       "German (de) translation" ],
        [ "Fabrizio Margini",    "Italian (it) translation" ],
        [ "Tanaka Hidemune",     "Japanese (ja) translation and user reference manual" ],
        [ "Евгений, AlexL",      "Russian (ru) translation" ],
        [ "Ján Jamriška",        "Slovak (sk) translation" ],
        [ "Miha ('miharix')",    "Slovenian (sl) translation" ],
        [ "oltulu",              "Turkish (tr) translation" ],
        [ "Piotr Sokół",         "Polish (pl) translation" ],
        [ "Eduardo Passeto",     "Portuguese (pt) translation" ],
    ],
    [
        qsTr("Templates"),
        [ "Clive Tubb ('clive')", "ISO/AEC templates" ],
        [ "Frank ('DL3DL')",   "German templates DIN6771-1, DIN7200" ],
        [ "Miha ('miharix')",  "Slowenian Templates (OŠ)" ],
    ],
    [
        qsTr("Icons"),
        [ "Ralf Blumhagen ('blumi')",   "Icons for Apollonius tools in Misc > Drawing" ],
    ],
    [
        qsTr("Testing, Feedback and Minor Fixes"),
        [ "Clive Tubb ('clive')", "" ],
        [ "Harald Huesges ('Husky')", "" ],
        [ "and many others", "" ],
    ]
];
